import { Type, TemplateRef } from '@angular/core';
import { AbstractControlOptions } from '@angular/forms';
import { SVW_RELATIONS } from './constants';
import { SvwJsonGraphql, GraphqlFilters } from './interfaces-graphql';
import { SvwJsonRest } from './interfaces-rest';
import { FiltersLoad } from '../services/serviw-rest';
import * as C from './../world';
export declare type TypeOfType<S> = {
    readonly [P in keyof S]: S[P];
};
export declare type JsonStorage<S> = TypeOfType<S>;
export declare type JsonStorageGraphql<S = any> = {
    readonly [P in keyof S]: SvwJsonGraphql<any, S>;
};
export declare type JsonStorageRest<S = any> = {
    readonly [P in keyof S]: SvwJsonRest<any, S>;
};
export declare type JsonStorageSchema<S> = JsonStorageGraphql<S> | JsonStorageRest<S>;
export declare type TypeProperties<F, S> = {
    [P in keyof F]: S;
};
export interface SvwJson {
    titleForm?: string;
    titleTable?: string;
    first?: number;
    displayField?: string;
    filterDelay?: number;
    settings?: JsonSettings;
    /**
     * CRUD
     * @description default { read: true, create: true, update: true }
     */
    operations?: Operations;
    emptyDataMessage?: boolean;
    /** @example { 'create': 'Nuevo', 'update': 'Editar', 'delete': 'Eliminar', 'save': 'Guardar', 'cancelSave': 'Cancelar' } */
    buttons?: {
        [name: string]: string;
    };
    /** @example { 'update', 'delete', 'save' } */
    messages?: {
        [name: string]: string;
    };
    /** Campos para validaciones en grupos */
    uniqueFields?: {
        [group: string]: {
            fields: string[];
            error: string;
        };
    };
    /** Campo para validaciones */
    uniqueField?: {
        fields: string;
        error: string;
    };
}
/** Operations CRUD */
export interface Operations {
    read?: boolean;
    create?: boolean;
    update?: boolean;
    delete?: boolean;
}
/** Html settings configurations by frameworks */
export interface JsonSettings {
    table?: {
        [name: string]: any;
    };
    form?: {
        [name: string]: any;
    };
}
/** Svw properties */
export interface SvwProperties {
    [name: string]: SvwProperty;
}
/** Svw property */
export interface SvwProperty<S = any> {
    id?: boolean;
    label?: string;
    filterType?: string;
    showForm?: boolean;
    showDynamic?: boolean;
    type?: 'string' | 'int' | 'float' | 'date' | 'double' | 'long' | 'boolean';
    template?: 'number' | 'text' | 'date' | 'email' | 'password' | 'radiobutton' | 'select' | 'checkbox' | 'autocomplete' | 'textarea' | 'file' | typeof C.MANY_TO_ONE | typeof C.MANY_TO_MANY | typeof C.ONE_TO_MANY | 'editor';
    templatesTable?: {
        row?: TemplateRef<any>;
        footer?: TemplateRef<any>;
    };
    templatesForm?: {
        field?: TemplateRef<any>;
    };
    /**  manyToMany -> nullable:true     */
    relation?: SVW_RELATIONS;
    inversedBy?: string;
    value?: any;
    validations?: SvwValidators;
    options?: SvwOptions[];
    disable?: boolean;
    inputType?: string;
    /**  type : file -> inputType : img | pdf | word  */
    inputAccept?: string;
    displayColumn?: boolean;
    readonly?: boolean;
    loading?: boolean;
    /** it is recommended to use  showDynamic:true  */
    toogle?: (val?: boolean) => void;
    readonly json?: Extract<keyof S, string>;
    /**
     * @example 'true' -> field;
     * @example GRAPHQL manyToOne
     *  field: municipio
     *  orderBy: "id"
     *
     *  in query -> municipio_id
     */
    orderBy?: string;
    startOrderBy?: 'asc' | 'desc';
    tooltip?: string;
    icon?: string;
    /** other settings */
    settings?: any;
    /** omitir imput en graphql    */
    omitInput?: boolean;
    /** Omitir fields graphql */
    omitField?: boolean;
}
/** Svw validators */
export interface SvwValidators {
    nullable?: boolean;
    max?: number;
    min?: number;
    maxLength?: number;
    minLength?: number;
    pattern?: string | RegExp;
    email?: boolean;
    unique?: boolean;
    minIn?: string;
    maxIn?: string;
    minDate?: Date;
    maxDate?: Date;
    equalsIn?: string;
    errors?: {
        nullable?: string;
        max?: string;
        min?: string;
        maxLength?: string;
        minLength?: string;
        minIn?: string;
        maxIn?: string;
        email?: string;
        unique?: string;
        pattern?: string;
        minDate?: string;
        maxDate?: string;
        equalsIn?: string;
    };
}
/** Validation */
export interface Validation {
    [key: string]: any;
    options?: AbstractControlOptions | {
        [key: string]: any;
    } | null;
}
/** Svw form templates */
export interface SvwFormTemplates {
    number?: {
        template: Type<any>;
        divClass?: string;
    };
    text?: {
        template: Type<any>;
        divClass?: string;
    };
    date?: {
        template: Type<any>;
        divClass?: string;
    };
    email?: {
        template: Type<any>;
        divClass?: string;
    };
    password?: {
        template: Type<any>;
        divClass?: string;
    };
    radiobutton?: {
        template: Type<any>;
        divClass?: string;
    };
    select?: {
        template: Type<any>;
        divClass?: string;
    };
    checkbox?: {
        template: Type<any>;
        divClass?: string;
    };
    manyToOne?: {
        template: Type<any>;
        divClass?: string;
    };
    autocomplete?: {
        template: Type<any>;
        divClass?: string;
    };
    textarea?: {
        template: Type<any>;
        divClass?: string;
    };
    file?: {
        template: Type<any>;
        divClass?: string;
    };
    manyToMany?: {
        template: Type<any>;
        divClass?: string;
    };
    editor?: {
        template: Type<any>;
        divClass?: string;
        config?: any;
    };
    actions?: {
        template: Type<any>;
        divClass?: string;
        config?: any;
    };
}
/** Svw table template */
export interface SvwTableTemplate {
    template: Type<any>;
    divClass?: string;
}
/** Svw form events */
export interface SvwBeforeSave<I> {
    value: I;
    readonly continue: (value?: I) => Promise<any>;
}
/** Svw after save */
export interface SvwAfterSave<I> {
    readonly value: I;
    readonly create: boolean;
    readonly errors?: any;
    readonly error?: string;
    /** Emite mensaje de error en serviwGrowl.error, si existe */
    readonly viewError: (detail?: string) => void;
}
/** Error exception */
export declare class ErrorException {
    static readonly ERROR_NETWORK = "network_error";
    static readonly ERROR_VALIDATION = "validation_error";
    static readonly ERROR_USER = "user_error";
    static readonly ERROR_VAR_INCOMPLETE = "var_imcomplete_error";
    cause: any;
    stackTrace: any;
    message?: string;
    localizedMessage?: string;
    suppressed: any;
    constructor(message: string, cause?: string, localizedMessage?: string, supressed?: any);
}
/** Svw message */
export interface SvwMessage {
    icon?: string;
    severity?: string;
    summary?: string;
    detail?: string;
    id?: any;
    key?: string;
    duration?: number;
    data?: any;
}
/** Svw filter table */
export interface SvwFilterTable {
    column: string;
    value: any;
}
/** Data form */
export interface DataForm<I> {
    json: SvwJsonGraphql<I> | SvwJsonRest<I>;
    data?: I;
    queryKey?: boolean;
    parent?: {
        table: string;
        value: string | number;
    };
}
/** Lazy load event */
export interface LazyLoadEvent {
    first?: number;
    rows?: number;
    sortField?: string;
    sortOrder?: number;
    filters?: FiltersLoad;
    globalFilter?: any;
}
/** Filter table */
export interface FilterTable<F extends LazyLoadEvent | GraphqlFilters> {
    params?: F;
    continue?: (params?: F) => void;
}
/** Svw options */
export interface SvwOptions {
    label: string;
    value: string;
    icon?: string;
}
/** Query single */
export interface QuerySingle<I> {
    refactor: (response: any) => I;
    http: () => Promise<any>;
}
/** Refactor query */
export interface RefactorQuery {
    query?: any;
    refactor: (response: any) => Array<any>;
    getOptions?: (response: any, fieldLabel?: string) => Array<any>;
    http: () => Promise<any>;
    /** @deprecated implement getError */
    getError?: (response: any) => string;
}
//# sourceMappingURL=interfaces.d.ts.map